@@ -12,7 +12,7 @@ __all__ = ['IProblemConverter', 'convert_problem']
 
 import copy
 import os
-from formats import ProblemFormat
+from formats import ProblemFormat, guess_format
 from error import *
 from pyutilib.component.core import *
 
@@ -47,14 +47,9 @@ def convert_problem(args, target_problem_type, valid_problem_types):
        fname = tmp.split(os.sep)[-1]
        if os.sep in fname:   #pragma:nocover
           fname = tmp.split(os.sep)[-1]
-       suffix = fname.split('.')[-1]
-       try:
-          if suffix == "lp":
-             source_ptype = [ProblemFormat.cpxlp]
-          else:
-             source_ptype = [getattr(ProblemFormat,suffix)]
-       except AttributeError:
-          raise ConverterError, "Unknown suffix type: "+suffix
+       source_ptype = [guess_format(fname)]
+       if source_ptype is [None]:
+            raise ConverterError, "Unknown suffix type: "+suffix
     else:
        source_ptype = args[0].valid_problem_types()
 
