@@ -32,17 +32,31 @@ class ScalarData(object):
         self.scalar_type = type
         self._required=required
 
-    def _repn_(self, option):
-        if not option.schema and not self._required and self.value is undefined:
-            return ignore
-        if option.ignore_time and str(self.scalar_type) == str(ScalarType.time):
-            return ignore
+    def get_value(self):
         if type(self.value) is EnumValue:
             value = str(self.value)
         elif type(self.value) is UndefinedData:
             value = '<undefined>'
         else:
             value = self.value
+        return value
+
+    def _repn_(self, option):
+        if not option.schema and not self._required and self.value is undefined:
+            return ignore
+        if option.ignore_time and str(self.scalar_type) == str(ScalarType.time):
+            return ignore
+        value = self.get_value()
+        #
+        # Disabled logic for managing default values, and the
+        # ignore_defaults option
+        #
+        #if option.ignore_defaults:
+        #    try:
+        #        if self._default == value:
+        #            return ignore
+        #    except AttributeError:
+        #        pass
         if option.schema:
             tmp = {'value':value}
             if not self.description is None:
@@ -68,12 +82,7 @@ class ScalarData(object):
             return ignore
         if option.ignore_time and str(self.scalar_type) == str(ScalarType.time):
             return ignore
-        if type(self.value) is EnumValue:
-            value = self.yaml_fix(str(self.value))
-        elif type(self.value) is UndefinedData:
-            value = '<undefined>'
-        else:
-            value = self.yaml_fix(self.value)
+        value = self.yaml_fix(self.get_value())
         if not option.schema and self.description is None and self.units is None:
             print >>ostream, value
         else:
@@ -277,6 +286,13 @@ class MapContainer(dict):
             data = ScalarData(**kwds)
             if 'required' in kwds and kwds['required'] is True:
                 data._required = True
+            #
+            # This logic would setup a '_default' value, which copies the
+            # initial value of an attribute.  I don't think we need this,
+            # but for now I'm going to leave this logic in the code.
+            #
+            #if 'value' in kwds:
+            #    data._default = kwds['value']
             dict.__setitem__(self, tmp, data)
 
     def _repn_(self, option):
@@ -334,6 +350,7 @@ class MapContainer(dict):
             if tmp not in self:
                 self.declare(tmp)
             item = dict.__getitem__(self,tmp)
+            item._active=True
             item.load(repn[key])
 
     def __getstate__(self):
