@@ -15,7 +15,7 @@ from pyutilib.misc import Bunch
 from pyutilib.enum import Enum
 from pyutilib.math import as_number
 
-default_print_options = Bunch(schema=False, sparse=True, num_solutions=None, ignore_time=False)
+default_print_options = Bunch(schema=False, sparse=True, num_solutions=None, ignore_time=False, ignore_defaults=False)
 
 SolutionStatus = Enum('globallyOptimal', 'locallyOptimal',
                             'optimal', 'bestSoFar', 'feasible', 'infeasible', 'stoppedByLimit',
@@ -176,7 +176,7 @@ class SolutionMap(MapContainer):
             MapContainer.pprint(self, ostream, option, from_list=from_list, prefix=prefix, repn=repn)
 
     def load(self, repn):
-        if isinstance(repn, basestring):
+        if isinstance(repn, basestring) or repn is None:
             return
         index = {}
         for key in repn:
