@@ -10,16 +10,15 @@ sys.path.insert(0, dirname(dirname(abspath(__file__)))+"/../..")
 cooprdir = dirname(abspath(__file__))+os.sep+".."+os.sep+".."+os.sep
 currdir = dirname(abspath(__file__))+os.sep
 
-import unittest
 from nose.tools import nottest
 import coopr.opt
 import coopr
 import xml
-import pyutilib.th
+import pyutilib.th as unittest
 import pyutilib.services
 
 
-class Test(pyutilib.th.TestCase):
+class Test(unittest.TestCase):
 
     def setUp(self):
         pyutilib.services.TempfileManager.tempdir = currdir
